@@ -39,12 +39,15 @@ class FULL:
         with self.tokenizer.as_target_tokenizer():
             decoder_inputs =  self.tokenizer(decoder_inputs, truncation=True, return_tensors="pt")
         inputs["labels"] = decoder_inputs["input_ids"]
+        encoder_outputs = None
         with torch.no_grad():
             outputs = self.model(
                 input_ids=inputs["input_ids"].to(self.device),
                 labels=inputs["labels"].to(self.device),
+                encoder_outputs=encoder_outputs,
                 return_dict=True
             )
+            encoder_outputs = outputs.encoder_last_hidden_state
         return torch.exp(outputs["loss"]).item()
 
     def evaluate_turn(self, conversation: List[str], response: str):
@@ -57,7 +60,7 @@ class FULL:
         score = self._evaluate(conversation)
         return score
 
-    def evaluate_conversation(self, conversation: List[str]):
+    def evaluate_dialog(self, conversation: List[str]):
         assert isinstance(conversation, list), "the conversation should be a list"
         assert len(conversation) > 0, "the conversation should have at least one turn"
         assert all([isinstance(turn, str) for turn in conversation]), "all turns in a conversation should be str"
