@@ -22,7 +22,7 @@ def test_evaluate_turn():
     assert evaluation == pytest.approx(27.56904637813568)
 
 
-def test_evaluate_conversation():
+def test_evaluate_dialog():
     """ Test the evaluation returns the correct number """
     model = FULL()
     conversation = [
@@ -36,5 +36,5 @@ def test_evaluate_conversation():
         'What kind of meeting?', 
         "Can't say"
     ]
-    evaluation = model.evaluate_conversation(conversation)
+    evaluation = model.evaluate_dialog(conversation)
     assert evaluation == pytest.approx(31.083410263061523)
\ No newline at end of file
